==> wasabiD-0.2.92.tgz: package/Base/Form/Form.jsx <==
//create by wangzy
//date:2016-02-19
//desc:表单组件，暂时只是简单模式
require("../../sass/Base/Form/Form.css");
var React=require("react");
var Input=require("./Input.jsx");
var Button=require("../Button/Button.jsx");
var alogUtil=require("../../libs/alogUtil.js");
var Form=React.createClass({
    propTypes: {
        model:React.PropTypes.array.isRequired,
        submitHandler:React.PropTypes.func,
        closeHandler:React.PropTypes.func,
        submitTitle:React.PropTypes.string,
        copyTitle:React.PropTypes.string,
        closeTitle:React.PropTypes.string,
        submitHide:React.PropTypes.bool,
        copyHide:React.PropTypes.bool,
        closeHide:React.PropTypes.bool,
        disabled:React.PropTypes.bool,
    },
    getDefaultProps:function() {
      return {
          model: [],//表单数据模型
          disabled:false,//是否只读
          submitHandler: null,//提交成功后的回调事件
          closeHandler:null,//关闭事件
          submitTitle:"提交",//提交按钮标题
          copyTitle:"确定并复制",//确定并复制按钮标题
          closeTitle:"关闭",//关闭按钮标题
          submitHide:false,//提交按钮是否隐藏
          copyHide:false,//确定并复制按钮是否隐藏
          closeHide:false,//关闭按钮是否隐藏
          className:"",//自定义样式
      }

    },
    getInitialState:function() {
        return{
            model:(this.props.model),//一定复制
            disabled:this.props.disabled

        }
    },
    componentWillReceiveProps:function(nextProps) {
        this.setState({
            model:( nextProps.model),
            disabled:nextProps.disabled
        })
    },
    changeHandler:function(value,text,name) {
        //子组件值发生改变时
      var newModel=this.state.model;
        for(var i=0;i<newModel.length;i++)
        {
            if(newModel[i].name==name)
            {
                newModel[i].value=value;
                newModel[i].text=text;
                break ;
            }
        }
        this.setState({
            model:newModel
        })
    },
    getData:function() {//获取当前表单的数据，没有验证
        var data={};
        let isva=true;
        for(let v in this.refs)
        {
            if(isva) {
                //验证成功，则继续验证
                isva = this.refs[v].validate(this.refs[v].state.value);
            }else
            {//不成功则继续验证但不再回执
                this.refs[v].validate(this.refs[v].state.value);
            }

            if(this.refs[v].props.name.indexOf(",")>-1)
            {//含有多个字段
                 var nameSplit=this.refs[v].props.name.split(",");
                if(this.refs[v].state.value&&this.refs[v].state.value!="")
                {
                    var valueSplit=this.refs[v].state.value.split(",");
                    for(let index =0;index<nameSplit.length;index++)
                    {
                        if(index<valueSplit.length)
                        {
                            data[nameSplit[index]]=valueSplit[index];
                        }
                    }

                }
                else
                {
                    for(let index =0;index<nameSplit.length;index++)
                    {
                            data[nameSplit[index]]=null;
                    }
                }
            }
            else
            {
                data[this.refs[v].props.name]=this.refs[v].state.value;
            }

        }
        if(isva)
        {
            return data;
        }
        else {
            return null;
        }

    },
    getTextData:function() {
        var textData={};//各个字段对应的文本值
        let isva=true;
        for(let v in this.refs)
        {
            if(isva) {
                //验证成功，则继续验证
                isva = this.refs[v].validate(this.refs[v].state.value);
            }else
            {//不成功则继续验证但不再回执
                this.refs[v].validate(this.refs[v].state.value);
            }
            if(this.refs[v].props.name.indexOf(",")>-1) {//含有多个字段
                var nameSplit=this.refs[v].props.name.split(",");
                if(this.refs[v].state.value&&this.refs[v].state.value!="")
                {

                    var textSplit=this.refs[v].state.text.split(",");//文本值
                    for(let index =0;index<nameSplit.length;index++)
                    {
                        if(index<textSplit.length)
                        {
                            textData[nameSplit[index]]=textSplit[index];
                        }
                    }

                }
                else
                {
                    for(let index =0;index<nameSplit.length;index++)
                    {
                            textData[nameSplit[index]]="";
                    }
                }
            }
            else
            {
                textData[this.refs[v].props.name]=this.refs[v].state.text;


            }

        }
        if(isva)
        {
            return textData;
        }
        else {
            return null;
        }
    },
    getModel:function() {
        //获取当前表单数据model
       var newmodel=(this.state.model);//
        return newmodel;
    },
    validate:function() {
        var data={}
        let isva=true;
        for(let v in this.refs)
        {
            if(isva) {
                //验证成功，则继续验证
                isva = this.refs[v].validate(this.refs[v].state.value);
            }else
            {//不成功则继续验证但不再回执
                this.refs[v].validate(this.refs[v].state.value);
            }
            data[this.refs[v].props.name]=this.refs[v].state.value;
        }
        return isva;
    },
    getComponentData:function(name) {//只读属性，获取对应的字段的数据源
      return  JSON.parse(window.localStorage.getItem(name+"data"))
    },
    clearData:function() {//清空数据
      var newModel=this.state.model;
        for(let i=0;i<newModel.length;i++)
        {
            newModel[i].value=null;
            newModel[i].text=null;
        }
        this.setState({
            model:newModel
        })
    },
    onSubmit:function(type) {
        //提交 数据
            var data={};//各个字段对应的值
            var textData={};//各个字段对应的文本值
            let isva=true;
         for(let v in this.refs)
            {
                if(isva) {
                    //验证成功，则继续验证
                    isva = this.refs[v].validate(this.refs[v].state.value);
                }else
                {//不成功则继续验证但不再回执
                    this.refs[v].validate(this.refs[v].state.value);
                }
                if(this.refs[v].props.name.indexOf(",")>-1) {//含有多个字段
                    var nameSplit=this.refs[v].props.name.split(",");
                    if(this.refs[v].state.value&&this.refs[v].state.value!="")
                    {
                        var valueSplit=this.refs[v].state.value.split(",");
                        var textSplit=this.refs[v].state.text.split(",");//文本值
                        for(let index =0;index<nameSplit.length;index++)
                        {
                            if(index<valueSplit.length)
                            {
                                data[nameSplit[index]]=valueSplit[index];
                                textData[nameSplit[index]]=textSplit[index];
                            }
                        }

                    }
                    else {
                        for(let index =0;index<nameSplit.length;index++)
                        {
                            data[nameSplit[index]]=null;
                                textData[nameSplit[index]]="";
                        }
                    }
                }
                else
                {
                    data[this.refs[v].props.name]=this.refs[v].state.value;
                    textData[this.refs[v].props.name]=this.refs[v].state.text;


                }

            }
     if(isva) {
        if (type == "submit") {
            //如果是提交直接处理关闭事件
           this.closeHandler();

        }
        if(this.props.submitHandler!=null)
        {
            this.props.submitHandler(data,textData);
        }

    }
    },
    closeHandler:function() {//关闭事件
        if(this.props.closeHandler!=null)
        {
            this.props.closeHandler();
        }
    },
    render:function() {
        let formSubmitVisible=true;
        if(this.state.disabled||(this.props.submitHide&&this.props.copyHide&&this.props.closeHide))
        {
            formSubmitVisible=false;
        }
        return (
            <div className={"Form-container"}>
                        <div  className={"Form-body  "+this.props.className} style={this.props.style}>
                            {
                                this.state.model.map((child,i) =>{

                                return(
                                    <Input ref={child.name}
                                        key={child.name+i.toString()}
                                        {...child}
                                         readonly={this.state.disabled==true?true:child.readonly}
                                           backFormHandler={this.changeHandler}
                                    ></Input>
                                );
                                })
                            }

                        </div>
                        <div className="form-submit" style={{display:(formSubmitVisible==true?"block":"none")}}>
                    <Button  onClick={this.onSubmit.bind(this,"submit")} title={this.props.submitTitle}  style={{     display:this.state.disabled==true?"none":this.props.submitHide==true?"none":"inline"}}  >
                        {this.props.submitTitle}
                    </Button>
                    <Button   onClick={this.onSubmit.bind(this,"copy")} title={this.props.copyTitle} style={{     display:this.state.disabled==true?"none":this.props.copyHide==true?"none":"inline"}} >
                        {this.props.copyTitle}
                    </Button>
                    <Button    onClick={this.closeHandler}  title={this.props.closeTitle} style={{ display:this.state.disabled==true?"none":this.props.closeHide==true?"none":"inline"}}  >
                        {this.props.closeTitle}
                    </Button>
                </div>
                </div>
        )
    }
});
module.exports=Form;

==> wasabiD-0.2.983.tgz: package/Base/Form/Form.jsx <==
//create by wangzy
//date:2016-02-19
//desc:表单组件，暂时只是简单模式
require("../../sass/Base/Form/Form.css");
var React=require("react");
var Input=require("./Input.jsx");
var Button=require("../Buttons/Button.jsx");
var unit=require("../../libs/unit.js");
var Form=React.createClass({
    propTypes: {
        model:React.PropTypes.array.isRequired,
        submitHandler:React.PropTypes.func,
        closeHandler:React.PropTypes.func,
        submitTitle:React.PropTypes.string,
        copyTitle:React.PropTypes.string,
        closeTitle:React.PropTypes.string,
        submitHide:React.PropTypes.bool,
        copyHide:React.PropTypes.bool,
        closeHide:React.PropTypes.bool,
        disabled:React.PropTypes.bool,
    },
    getDefaultProps:function() {
      return {
          model: [],//表单数据模型
          disabled:false,//是否只读
          submitHandler: null,//提交成功后的回调事件
          closeHandler:null,//关闭事件
          submitTitle:"提交",//提交按钮标题
          copyTitle:"确定并复制",//确定并复制按钮标题
          closeTitle:"关闭",//关闭按钮标题
          submitHide:false,//提交按钮是否隐藏
          copyHide:false,//确定并复制按钮是否隐藏
          closeHide:false,//关闭按钮是否隐藏
          className:"",//自定义样式
      }

    },
    getInitialState:function() {
        return{
            model:(this.props.model),//一定复制
            disabled:this.props.disabled

        }
    },
    componentWillReceiveProps:function(nextProps) {
        this.setState({
            model:( nextProps.model),
            disabled:nextProps.disabled
        })
    },
    changeHandler:function(value,text,name) {
        //子组件值发生改变时
      var newModel=this.state.model;
        for(var i=0;i<newModel.length;i++)
        {
            if(newModel[i].name==name)
            {
                newModel[i].value=value;
                newModel[i].text=text;
                break ;
            }
        }
        this.setState({
            model:newModel
        })
    },
    getData:function() {//获取当前表单的数据，没有验证
        var data={};
        let isva=true;
        for(let v in this.refs)
        {
            if(isva) {
                //验证成功，则继续验证
                isva = this.refs[v].validate(this.refs[v].state.value);
            }else
            {//不成功则继续验证但不再回执
                this.refs[v].validate(this.refs[v].state.value);
            }

            if(this.refs[v].props.name.indexOf(",")>-1)
            {//含有多个字段
                 var nameSplit=this.refs[v].props.name.split(",");
                if(this.refs[v].state.value&&this.refs[v].state.value!="")
                {
                    var valueSplit=this.refs[v].state.value.split(",");
                    for(let index =0;index<nameSplit.length;index++)
                    {
                        if(index<valueSplit.length)
                        {
                            data[nameSplit[index]]=valueSplit[index];
                        }
                    }

                }
                else
                {
                    for(let index =0;index<nameSplit.length;index++)
                    {
                            data[nameSplit[index]]=null;
                    }
                }
            }
            else
            {
                data[this.refs[v].props.name]=this.refs[v].state.value;
            }

        }
        if(isva)
        {
            return data;
        }
        else {
            return null;
        }

    },
    getTextData:function() {
        var textData={};//各个字段对应的文本值
        let isva=true;
        for(let v in this.refs)
        {
            if(isva) {
                //验证成功，则继续验证
                isva = this.refs[v].validate(this.refs[v].state.value);
            }else
            {//不成功则继续验证但不再回执
                this.refs[v].validate(this.refs[v].state.value);
            }
            if(this.refs[v].props.name.indexOf(",")>-1) {//含有多个字段
                var nameSplit=this.refs[v].props.name.split(",");
                if(this.refs[v].state.value&&this.refs[v].state.value!="")
                {

                    var textSplit=this.refs[v].state.text.split(",");//文本值
                    for(let index =0;index<nameSplit.length;index++)
                    {
                        if(index<textSplit.length)
                        {
                            textData[nameSplit[index]]=textSplit[index];
                        }
                    }

                }
                else
                {
                    for(let index =0;index<nameSplit.length;index++)
                    {
                            textData[nameSplit[index]]="";
                    }
                }
            }
            else
            {
                textData[this.refs[v].props.name]=this.refs[v].state.text;


            }

        }
        if(isva)
        {
            return textData;
        }
        else {
            return null;
        }
    },
    getModel:function() {
        //获取当前表单数据model
       var newmodel=(this.state.model);//
        return newmodel;
    },
    validate:function() {
        var data={}
        let isva=true;
        for(let v in this.refs)
        {
            if(isva) {
                //验证成功，则继续验证
                isva = this.refs[v].validate(this.refs[v].state.value);
            }else
            {//不成功则继续验证但不再回执
                this.refs[v].validate(this.refs[v].state.value);
            }
            data[this.refs[v].props.name]=this.refs[v].state.value;
        }
        return isva;
    },
    getComponentData:function(name) {//只读属性，获取对应的字段的数据源
      return  JSON.parse(window.localStorage.getItem(name+"data"))
    },
    clearData:function() {//清空数据
      var newModel=this.state.model;
        for(let i=0;i<newModel.length;i++)
        {
            newModel[i].value=null;
            newModel[i].text=null;
        }
        this.setState({
            model:newModel
        })
    },
    onSubmit:function(type) {
        //提交 数据
            var data={};//各个字段对应的值
            var textData={};//各个字段对应的文本值
            let isva=true;
         for(let v in this.refs)
            {
                if(isva) {
                    //验证成功，则继续验证
                    isva = this.refs[v].validate(this.refs[v].state.value);
                }else
                {//不成功则继续验证但不再回执
                    this.refs[v].validate(this.refs[v].state.value);
                }
                if(this.refs[v].props.name.indexOf(",")>-1) {//含有多个字段
                    var nameSplit=this.refs[v].props.name.split(",");
                    if(this.refs[v].state.value&&this.refs[v].state.value!="")
                    {
                        var valueSplit=this.refs[v].state.value.split(",");
                        var textSplit=this.refs[v].state.text.split(",");//文本值
                        for(let index =0;index<nameSplit.length;index++)
                        {
                            if(index<valueSplit.length)
                            {
                                data[nameSplit[index]]=valueSplit[index];
                                textData[nameSplit[index]]=textSplit[index];
                            }
                        }

                    }
                    else {
                        for(let index =0;index<nameSplit.length;index++)
                        {
                            data[nameSplit[index]]=null;
                                textData[nameSplit[index]]="";
                        }
                    }
                }
                else
                {
                    data[this.refs[v].props.name]=this.refs[v].state.value;
                    textData[this.refs[v].props.name]=this.refs[v].state.text;


                }

            }
     if(isva) {
        if (type == "submit") {
            //如果是提交直接处理关闭事件
           this.closeHandler();

        }
        if(this.props.submitHandler!=null)
        {
            this.props.submitHandler(data,textData);
        }

    }
    },
    closeHandler:function() {//关闭事件
        if(this.props.closeHandler!=null)
        {
            this.props.closeHandler();
        }
    },
    render:function() {
        let formSubmitVisible=true;
        if(this.state.disabled||(this.props.submitHide&&this.props.copyHide&&this.props.closeHide))
        {
            formSubmitVisible=false;
        }
        return (
            <div className={"Form-container"}>
                        <div  className={"Form-body  "+this.props.className} style={this.props.style}>
                            {
                                this.state.model.map((child,i) =>{

                                return(
                                    <Input ref={child.name}
                                        key={child.name+i.toString()}
                                        {...child}
                                         readonly={this.state.disabled==true?true:child.readonly}
                                           backFormHandler={this.changeHandler}
                                    ></Input>
                                );
                                })
                            }

                        </div>
                        <div className="form-submit" style={{display:(formSubmitVisible==true?"block":"none")}}>
                    <Button  onClick={this.onSubmit.bind(this,"submit")} title={this.props.submitTitle}  style={{     display:this.state.disabled==true?"none":this.props.submitHide==true?"none":"inline"}}  >
                        {this.props.submitTitle}
                    </Button>
                    <Button   onClick={this.onSubmit.bind(this,"copy")} title={this.props.copyTitle} style={{     display:this.state.disabled==true?"none":this.props.copyHide==true?"none":"inline"}} >
                        {this.props.copyTitle}
                    </Button>
                    <Button    onClick={this.closeHandler}  title={this.props.closeTitle} style={{ display:this.state.disabled==true?"none":this.props.closeHide==true?"none":"inline"}}  >
                        {this.props.closeTitle}
                    </Button>
                </div>
                </div>
        )
    }
});
module.exports=Form;
